@@ -17,26 +17,33 @@ module XMonad.Config.Arossato
     ( -- * Usage
       -- $usage
       arossatoConfig
-    , arossatoTabbedConfig
     ) where
 
 import qualified Data.Map as M
+import System.IO (hPutStrLn)
 
-import XMonad
-import XMonad.ManageHook
+import XMonad hiding ( (|||) )
 import qualified XMonad.StackSet as W
 
 import XMonad.Actions.CycleWS
 import XMonad.Hooks.DynamicLog
+import XMonad.Hooks.ManageDocks
+import XMonad.Hooks.ServerMode
 import XMonad.Layout.Accordion
+import XMonad.Layout.LayoutCombinators
 import XMonad.Layout.Magnifier
 import XMonad.Layout.NoBorders
+import XMonad.Layout.SimpleFloat
 import XMonad.Layout.Tabbed
+import XMonad.Layout.WindowArranger
 import XMonad.Prompt
 import XMonad.Prompt.Shell
 import XMonad.Prompt.Ssh
+import XMonad.Prompt.Theme
 import XMonad.Prompt.Window
 import XMonad.Prompt.XMonad
+import XMonad.Util.Run
+import XMonad.Util.Themes
 
 -- $usage
 -- The simplest way to use this configuration module is to use an
@@ -48,8 +55,12 @@ import XMonad.Prompt.XMonad
 -- > import XMonad.Config.Arossato (arossatoConfig)
 -- >
 -- > main :: IO ()
--- > main = xmonad arossatoConfig
+-- > main = xmonad =<< arossatoConfig
 --
+-- NOTE: that I'm using xmobar and, if you don't have xmobar in your
+-- PATH, this configuration will produce an error and xmonad will not
+-- start. If you don't want to install xmobar get rid of this line at
+-- the beginning of 'arossatoConfig'.
 --
 -- You can use this module also as a starting point for writing your
 -- own configuration module from scratch. Save it as your
@@ -61,7 +72,6 @@ import XMonad.Prompt.XMonad
 -- >     ( -- * Usage
 -- >       -- $usage
 -- >       arossatoConfig
--- >     , arossatoTabbedConfig
 -- >     ) where
 --
 -- to
@@ -70,51 +80,52 @@ import XMonad.Prompt.XMonad
 --
 -- 2. Add a line like:
 --
--- > main = xmonad arossatoConfig
+-- > main = xmonad =<< arossatoConfig
 --
 -- 3. Start playing with the configuration options...;)
 
--- | My configuration for the Tabbed Layout. Basically this is the
--- Ion3 clean style.
-arossatoTabbedConfig :: TConf
-arossatoTabbedConfig =
-    defaultTConf { activeColor         = "#8a999e"
-                 , inactiveColor       = "#545d75"
-                 , activeBorderColor   = "white"
-                 , inactiveBorderColor = "grey"
-                 , activeTextColor     = "white"
-                 , inactiveTextColor   = "grey"
-                 , tabSize             = 15
-                 }
-
-arossatoConfig = defaultConfig
+arossatoConfig = do
+    xmobar <- spawnPipe "xmobar" -- REMOVE this line if you do not have xmobar installed!
+    return $ defaultConfig
          { workspaces         = ["home","var","dev","mail","web","doc"] ++
                                 map show [7 .. 9 :: Int]
-         , logHook            = dynamicLogXmobar
+         , logHook            = myDynLog xmobar -- REMOVE this line if you do not have xmobar installed!
          , manageHook         = newManageHook
-         , layoutHook         = noBorders mytab |||
-                                magnifier tiled |||
-                                noBorders Full  |||
-                                tiled           |||
-                                Mirror tiled    |||
-                                Accordion
+         , layoutHook         = eventHook ServerMode $
+                                avoidStruts $
+                                decorated        |||
+                                noBorders mytabs |||
+                                otherLays
          , terminal           = "urxvt +sb"
          , normalBorderColor  = "white"
          , focusedBorderColor = "black"
          , keys               = newKeys
-         , defaultGaps        = [(15,0,0,0)]
+         , focusFollowsMouse  = False
          }
     where
       -- layouts
-      mytab = tabbed shrinkText arossatoTabbedConfig
-      tiled = Tall 1 (3/100) (1/2)
+      mytabs    =       tabbed shrinkText (theme smallClean)
+      decorated = simpleFloat' shrinkText (theme smallClean)
+      tiled     = Tall 1 (3/100) (1/2)
+      otherLays = windowArrange   $
+                  magnifier tiled |||
+                  noBorders Full  |||
+                  Mirror tiled    |||
+                  Accordion
 
       -- manageHook
-      myManageHook  = composeAll [ resource =? "realplay.bin" --> doFloat
-                                 , resource =? "win"          --> doF (W.shift "doc") -- xpdf
+      myManageHook  = composeAll [ resource =? "win"          --> doF (W.shift "doc") -- xpdf
                                  , resource =? "firefox-bin"  --> doF (W.shift "web")
                                  ]
-      newManageHook = myManageHook <+> manageHook defaultConfig
+      newManageHook = myManageHook
+
+      -- xmobar
+      myDynLog    h = dynamicLogWithPP defaultPP
+                      { ppCurrent = xmobarColor "yellow" "" . wrap "[" "]"
+                      , ppTitle   = xmobarColor "green"  "" . shorten 40
+                      , ppVisible = wrap "(" ")"
+                      , ppOutput  = hPutStrLn h
+                      }
 
       -- key bindings stuff
       defKeys    = keys defaultConfig
@@ -136,8 +147,9 @@ arossatoConfig = defaultConfig
           [ ((modMask x              , xK_F12   ), xmonadPrompt      defaultXPConfig     )
           , ((modMask x              , xK_F3    ), shellPrompt       defaultXPConfig     )
           , ((modMask x              , xK_F4    ), sshPrompt         defaultXPConfig     )
-          , ((modMask x              , xK_F5    ), windowPromptGoto  defaultXPConfig     )
-          , ((modMask x              , xK_F6    ), windowPromptBring defaultXPConfig     )
+          , ((modMask x              , xK_F5    ), themePrompt       defaultXPConfig     )
+          , ((modMask x              , xK_F6    ), windowPromptGoto  defaultXPConfig     )
+          , ((modMask x              , xK_F7    ), windowPromptBring defaultXPConfig     )
           , ((modMask x              , xK_comma ), prevWS                                )
           , ((modMask x              , xK_period), nextWS                                )
           , ((modMask x              , xK_Right ), windows W.focusDown                   )
@@ -155,6 +167,20 @@ arossatoConfig = defaultConfig
           , ((modMask x .|. controlMask              , xK_minus), sendMessage MagnifyLess)
           , ((modMask x .|. controlMask              , xK_o    ), sendMessage ToggleOff  )
           , ((modMask x .|. controlMask .|. shiftMask, xK_o    ), sendMessage ToggleOn   )
+          -- windowArranger
+          , ((modMask x .|. controlMask              , xK_a    ), sendMessage  Arrange           )
+          , ((modMask x .|. controlMask .|. shiftMask, xK_a    ), sendMessage  DeArrange         )
+          , ((modMask x .|. controlMask              , xK_Left ), sendMessage (DecreaseLeft   10))
+          , ((modMask x .|. controlMask              , xK_Up   ), sendMessage (DecreaseUp     10))
+          , ((modMask x .|. controlMask              , xK_Right), sendMessage (IncreaseRight  10))
+          , ((modMask x .|. controlMask              , xK_Down ), sendMessage (IncreaseDown   10))
+          , ((modMask x .|. shiftMask                , xK_Left ), sendMessage (MoveLeft       10))
+          , ((modMask x .|. shiftMask                , xK_Right), sendMessage (MoveRight      10))
+          , ((modMask x .|. shiftMask                , xK_Down ), sendMessage (MoveDown       10))
+          , ((modMask x .|. shiftMask                , xK_Up   ), sendMessage (MoveUp         10))
+          -- gaps
+          , ((modMask x                              , xK_b    ), sendMessage  ToggleStruts      )
+
           ] ++
           -- Use modMask .|. shiftMask .|. controlMask 1-9 instead
           [( (m .|. modMask x, k), windows $ f i)
