@@ -30,12 +30,14 @@ module XMonad.Layout.WorkspaceDir (
                                   ) where
 
 import System.Directory ( setCurrentDirectory, getCurrentDirectory )
+import Control.Monad ( when )
 
-import XMonad
+import XMonad hiding ( focus )
 import XMonad.Util.Run ( runProcessWithInput )
 import XMonad.Prompt ( XPConfig )
 import XMonad.Prompt.Directory ( directoryPrompt )
 import XMonad.Layout.LayoutModifier
+import XMonad.StackSet ( tag, current, workspace )
 
 -- $usage
 -- You can use this module with the following in your @~\/.xmonad\/xmonad.hs@:
@@ -66,8 +68,10 @@ instance Message Chdir
 
 data WorkspaceDir a = WorkspaceDir String deriving ( Read, Show )
 
-instance LayoutModifier WorkspaceDir a where
-    hook (WorkspaceDir s) = scd s
+instance LayoutModifier WorkspaceDir Window where
+    modifyLayout (WorkspaceDir d) w r = do tc <- gets (tag.workspace.current.windowset)
+                                           when (tc == tag w) $ scd d
+                                           runLayout w r
     handleMess (WorkspaceDir _) m
         | Just (Chdir wd) <- fromMessage m = do wd' <- cleanDir wd
                                                 return $ Just $ WorkspaceDir wd'
