@@ -1,5 +1,4 @@
 {-# LANGUAGE ExistentialQuantification #-}
-
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Prompt
@@ -14,32 +13,37 @@
 --
 -----------------------------------------------------------------------------
 
-module XMonad.Prompt (
-                             -- * Usage
-                             -- $usage
-                             mkXPrompt
-                             , mkXPromptWithReturn
-                             , defaultXPConfig
-                             , mkComplFunFromList
-                             , XPType (..)
-                             , XPPosition (..)
-                             , XPConfig (..)
-                             , XPrompt (..)
-                             , ComplFunction
-                             -- * X Utilities
-                             -- $xutils
-                             , mkUnmanagedWindow
-                             , fillDrawable
-                             -- * Other Utilities
-                             -- $utils
-                             , getLastWord
-                             , skipLastWord
-                             , splitInSubListsAt
-                             , breakAtSpace
-                             , newIndex
-                             , newCommand
-                             , uniqSort
-                             ) where
+module XMonad.Prompt
+    ( -- * Usage
+      -- $usage
+      mkXPrompt
+    , mkXPromptWithReturn
+    , defaultXPConfig
+    , XPType (..)
+    , XPPosition (..)
+    , XPConfig (..)
+    , XPrompt (..)
+    , ComplFunction
+    -- * X Utilities
+    -- $xutils
+    , mkUnmanagedWindow
+    , fillDrawable
+    -- * Other Utilities
+    -- $utils
+    , mkComplFunFromList
+    , mkComplFunFromList'
+    -- * @nextCompletion@ implementations
+    , getNextOfLastWord
+    , getNextCompletion
+    -- * List utilities
+    , getLastWord
+    , skipLastWord
+    , splitInSubListsAt
+    , breakAtSpace
+    , uniqSort
+    , decodeInput
+    , encodeOutput
+    ) where
 
 import XMonad  hiding (config, io)
 import qualified XMonad.StackSet as W
@@ -105,7 +109,10 @@ instance Show XPType where
     show (XPT p) = showXPrompt p
 
 instance XPrompt XPType where
-    showXPrompt = show
+    showXPrompt                 = show
+    nextCompletion      (XPT t) = nextCompletion      t
+    commandToComplete   (XPT t) = commandToComplete   t
+    completionToCommand (XPT t) = completionToCommand t
 
 -- | The class prompt types must be an instance of. In order to
 -- create a prompt you need to create a data type, without parameters,
@@ -118,8 +125,33 @@ instance XPrompt XPType where
 -- >     instance XPrompt Shell where
 -- >          showXPrompt Shell = "Run: "
 class XPrompt t where
+
+    -- | This method is used to print the string to be
+    -- displayed in the command line window.
     showXPrompt :: t -> String
 
+    -- | This method is used to generate the next completion to be
+    -- printed in the command line when tab is pressed, given the
+    -- string presently in the command line and the list of
+    -- completion.
+    nextCompletion :: t -> String -> [String] -> String
+    nextCompletion t c l = getNextOfLastWord t c l
+
+    -- | This method is used to generate the string to be passed to
+    -- the completion function.
+    commandToComplete :: t -> String -> String
+    commandToComplete _ c = getLastWord c
+
+    -- | This method is used to process each completion in order to
+    -- generate the string that will be compared with the command
+    -- presently displayed in the command line. If the prompt is using
+    -- 'getNextOfLastWord' for implementing 'nextCompletion' (the
+    -- default implementation), this method is also used to generate,
+    -- from the returned completion, the string that will form the
+    -- next command line when tab is pressed.
+    completionToCommand :: t -> String -> String
+    completionToCommand _ c = c
+
 data XPPosition = Top
                 | Bottom
                   deriving (Show,Read)
@@ -253,13 +285,14 @@ completionHandle ::  [String] -> KeyStroke -> Event -> XP ()
 completionHandle c (ks,_) (KeyEvent {ev_event_type = t})
     | t == keyPress && ks == xK_Tab = do
   st <- get
+  let updateState l = do let new_command = nextCompletion (xptype st) (command st) l
+                         modify $ \s ->  s { command = new_command, offset = length new_command }
+      updateWins  l = do redrawWindows l
+                         eventLoop (completionHandle l)
   case c of
-    [] -> do updateWindows
-             eventLoop handle
-    l  -> do let new_command = newCommand (command st) l
-             modify $ \s ->  s { command = new_command, offset = length new_command }
-             redrawWindows c
-             eventLoop (completionHandle c)
+    []  -> updateWindows   >> eventLoop handle
+    [x] -> updateState [x] >> getCompletions >>= updateWins
+    l   -> updateState l   >> updateWins l
 -- key release
     | t == keyRelease && ks == xK_Tab = eventLoop (completionHandle c)
 -- other keys
@@ -268,20 +301,6 @@ completionHandle _ ks (KeyEvent {ev_event_type = t, ev_state = m})
 -- some other event: go back to main loop
 completionHandle _ k e = handle k e
 
--- | Given a completion and a list of possible completions, returns the
--- index of the next completion in the list
-newIndex :: String -> [String] -> Int
-newIndex com cl =
-    case elemIndex (getLastWord com) cl of
-      Just i -> if i >= length cl - 1 then 0 else i + 1
-      Nothing -> 0
-
--- | Given a completion and a list of possible completions, returns the
--- the next completion in the list
-newCommand :: String -> [String] -> String
-newCommand com cl =
-    skipLastWord com ++ (cl !! (newIndex com cl))
-
 -- KeyPresses
 
 data Direction = Prev | Next deriving (Eq,Show,Read)
@@ -319,7 +338,7 @@ keyPressHandle mask (ks,_)
 -- insert a character
 keyPressHandle _ (_,s)
     | s == "" = eventLoop handle
-    | otherwise = do insertString s
+    | otherwise = do insertString (decodeInput s)
                      updateWindows
                      eventLoop handle
 
@@ -410,7 +429,7 @@ moveWord d = do
                  x     -> lenToS x
       newoff = case d of
                  Prev -> o - (ln reverse f )
-                 _    -> o + (ln id      ss)
+                 Next -> o + (ln id      ss)
   modify $ \s -> s { offset = newoff }
 
 moveHistory :: Direction -> XP ()
@@ -441,7 +460,7 @@ redrawWindows :: [String] -> XP ()
 redrawWindows c = do
   d <- gets dpy
   drawWin
-  case c  of
+  case c of
     [] -> return ()
     l  -> redrawComplWin l
   io $ sync d False
@@ -464,8 +483,8 @@ drawWin = do
       wh = widthOfScreen scr
       ht = height c
       bw = promptBorderWidth c
-  bgcolor <- io $ initColor d (bgColor c)
-  border  <- io $ initColor d (borderColor c)
+  Just bgcolor <- io $ initColor d (bgColor c)
+  Just border  <- io $ initColor d (borderColor c)
   p <- io $ createPixmap d w wh ht
                          (defaultDepthOfScreen scr)
   io $ fillDrawable d p gc border bgcolor (fi bw) wh ht
@@ -487,7 +506,7 @@ printPrompt drw = do
       ht = height c
   fsl <- io $ textWidthXMF (dpy st) fs f
   psl <- io $ textWidthXMF (dpy st) fs p
-  (_,asc,desc,_) <- io $ textExtentsXMF fs str
+  (asc,desc) <- io $ textExtentsXMF fs str
   let y = fi $ ((ht - fi (asc + desc)) `div` 2) + fi asc
       x = (asc + desc) `div` 2
 
@@ -504,7 +523,7 @@ printPrompt drw = do
 getCompletions :: XP [String]
 getCompletions = do
   s <- get
-  io $ (completionFunction s) (getLastWord $ command s)
+  io $ (completionFunction s) (commandToComplete (xptype s) (command s))
        `catch` \_ -> return []
 
 setComplWin :: Window -> ComplWindowDim -> XP ()
@@ -554,7 +573,7 @@ getComplWinDim compl = do
       (x,y) = case position c of
                 Top -> (0,ht)
                 Bottom -> (0, (0 + rem_height - actual_height))
-  (_,asc,desc,_) <- io $ textExtentsXMF fs $ head compl
+  (asc,desc) <- io $ textExtentsXMF fs $ head compl
   let yp = fi $ (ht + fi (asc - desc)) `div` 2
       xp = (asc + desc) `div` 2
       yy = map fi . take (fi actual_rows) $ [yp,(yp + ht)..]
@@ -565,13 +584,13 @@ getComplWinDim compl = do
 drawComplWin :: Window -> [String] -> XP ()
 drawComplWin w compl = do
   st <- get
-  let c = config st
-      d = dpy st
+  let c   = config st
+      d   = dpy st
       scr = defaultScreenOfDisplay d
-      bw = promptBorderWidth c
-      gc = gcon st
-  bgcolor <- io $ initColor d (bgColor c)
-  border  <- io $ initColor d (borderColor c)
+      bw  = promptBorderWidth c
+      gc  = gcon st
+  Just bgcolor <- io $ initColor d (bgColor c)
+  Just border  <- io $ initColor d (borderColor c)
 
   (_,_,wh,ht,xx,yy) <- getComplWinDim compl
 
@@ -620,7 +639,7 @@ printComplString :: Display -> Drawable -> GC -> String -> String
                  -> Position -> Position -> String  -> XP ()
 printComplString d drw gc fc bc x y s = do
   st <- get
-  if s == getLastWord (command st)
+  if completionToCommand (xptype st) s == commandToComplete (xptype st) (command st)
      then printStringXMF d drw (fontS st) gc
                             (fgHLight $ config st) (bgHLight $ config st) x y s
      else printStringXMF d drw (fontS st) gc fc bc x y s
@@ -698,6 +717,33 @@ mkComplFunFromList _ [] = return []
 mkComplFunFromList l s =
   return $ filter (\x -> take (length s) x == s) l
 
+-- | This function takes a list of possible completions and returns a
+-- completions function to be used with 'mkXPrompt'. If the string is
+-- null it will return all completions.
+mkComplFunFromList' :: [String] -> String -> IO [String]
+mkComplFunFromList' l [] = return l
+mkComplFunFromList' l s =
+  return $ filter (\x -> take (length s) x == s) l
+
+
+-- | Given the prompt type, the command line and the completion list,
+-- return the next completion in the list for the last word of the
+-- command line. This is the default 'nextCompletion' implementation.
+getNextOfLastWord :: XPrompt t => t -> String -> [String] -> String
+getNextOfLastWord t c l = skipLastWord c ++ completionToCommand t (l !! ni)
+    where ni = case commandToComplete t c `elemIndex` map (completionToCommand t) l of
+                 Just i -> if i >= length l - 1 then 0 else i + 1
+                 Nothing -> 0
+
+-- | An alternative 'nextCompletion' implementation: given a command
+-- and a completion list, get the next completion in the list matching
+-- the whole command line.
+getNextCompletion :: String -> [String] -> String
+getNextCompletion c l = l !! idx
+    where idx = case c `elemIndex` l of
+                  Just i  -> if i >= length l - 1 then 0 else i + 1
+                  Nothing -> 0
+
 -- Lift an IO action into the XP
 io :: IO a -> XP a
 io = liftIO
